# Revision History

## 1.0 (unreleased)

- Updated `html2text` to 2015.2.18.

## 0.1.3 (2014/12/05)

- Fixed missing logging messages.

## 0.1.2 (2014/02/11)

- Changed versioning method.

## 0.1.1 (2014/02/11)

- Switched to a package.

## 0.1 (2014/02/11)

- Initial release.
